Class: LittleGhost::AgentStreamStep
- Inherits:
-
Data
- Object
- Data
- LittleGhost::AgentStreamStep
- Defined in:
- lib/little_ghost/agent_stream_source.rb,
lib/little_ghost/agent_stream_source.rb
Overview
Identifies one assembly step in the path to a streamed Agent invocation. Paths list outer steps before inner steps, so the final value identifies the participant that directly contains the Agent.
Instance Attribute Summary collapse
-
#assembly_id ⇒ Object
readonly
Returns the value of attribute assembly_id.
-
#assembly_kind ⇒ Object
readonly
Returns the value of attribute assembly_kind.
-
#branch_id ⇒ Object
readonly
Returns the value of attribute branch_id.
-
#participant ⇒ Object
readonly
Returns the value of attribute participant.
-
#step_id ⇒ Object
readonly
Returns the value of attribute step_id.
Class Method Summary collapse
Instance Attribute Details
#assembly_id ⇒ Object (readonly)
Returns the value of attribute assembly_id
4 5 6 |
# File 'lib/little_ghost/agent_stream_source.rb', line 4 def assembly_id @assembly_id end |
#assembly_kind ⇒ Object (readonly)
Returns the value of attribute assembly_kind
4 5 6 |
# File 'lib/little_ghost/agent_stream_source.rb', line 4 def assembly_kind @assembly_kind end |
#branch_id ⇒ Object (readonly)
Returns the value of attribute branch_id
4 5 6 |
# File 'lib/little_ghost/agent_stream_source.rb', line 4 def branch_id @branch_id end |
#participant ⇒ Object (readonly)
Returns the value of attribute participant
4 5 6 |
# File 'lib/little_ghost/agent_stream_source.rb', line 4 def participant @participant end |
#step_id ⇒ Object (readonly)
Returns the value of attribute step_id
4 5 6 |
# File 'lib/little_ghost/agent_stream_source.rb', line 4 def step_id @step_id end |
Class Method Details
.build(assembly_id:, assembly_kind:, participant:, step_id:, branch_id: nil) ⇒ Object
:nodoc:
11 12 13 14 15 16 17 18 19 |
# File 'lib/little_ghost/agent_stream_source.rb', line 11 def self.build(assembly_id:, assembly_kind:, participant:, step_id:, branch_id: nil) # :nodoc: new( assembly_id: assembly_id.to_s.dup.freeze, assembly_kind: assembly_kind.to_sym, participant: participant.to_s.dup.freeze, step_id: step_id.to_s.dup.freeze, branch_id: branch_id&.to_s&.dup&.freeze ).freeze end |