Class: LittleGhost::GraphBuilder
- Inherits:
-
AssemblyBuilder
- Object
- AssemblyBuilder
- LittleGhost::GraphBuilder
- Defined in:
- lib/little_ghost/assembly_builder.rb
Overview
Builds a Graph from nodes and routes discovered at runtime.
Instance Attribute Summary
Attributes inherited from AssemblyBuilder
Class Method Summary collapse
-
.assembly_kind ⇒ Object
:nodoc:.
Instance Method Summary collapse
-
#initialize(**options) ⇒ GraphBuilder
constructor
Creates a mutable dynamic Graph definition.
-
#to_mermaid ⇒ Object
Renders the current validated snapshot as Mermaid flowchart text.
Methods inherited from AssemblyBuilder
#as_tool, #ask, #assembly_id, #assembly_kind, #build, #call, #definition, #description, #start_execution, #stream, #stream_ask, #validate!
Constructor Details
#initialize(**options) ⇒ GraphBuilder
Creates a mutable dynamic Graph definition.
418 419 420 421 |
# File 'lib/little_ghost/assembly_builder.rb', line 418 def initialize(**) super @declarations = [] end |
Class Method Details
.assembly_kind ⇒ Object
:nodoc:
414 |
# File 'lib/little_ghost/assembly_builder.rb', line 414 def assembly_kind = :graph |
Instance Method Details
#to_mermaid ⇒ Object
Renders the current validated snapshot as Mermaid flowchart text.
431 |
# File 'lib/little_ghost/assembly_builder.rb', line 431 def to_mermaid = definition.implementation.to_mermaid |