Exception: LittleGhost::InvocationError
- Defined in:
- lib/little_ghost/errors.rb
Overview
Raised when an invocation payload or operation is invalid.
Direct Known Subclasses
AgentBusyError, AgentInterjectionError, UnsupportedInputError
Raised when an invocation payload or operation is invalid.
AgentBusyError, AgentInterjectionError, UnsupportedInputError