Module: LittleGhost::ModelInterface
- Included in:
- Model
- Defined in:
- lib/little_ghost/model.rb
Overview
Interface for executable model implementations accepted by agents.
Instance Method Summary collapse
-
#capabilities ⇒ Object
Normalized feature support used for request strategy selection.
-
#details ⇒ Object
Immutable capabilities, limits, modalities, and pricing facts.
-
#model_id ⇒ Object
Provider-owned model identifier without the connection name.
-
#role ⇒ Object
Logical application role that selected this model, when available.
-
#target ⇒ Object
Canonical physical provider and model identifier.
Instance Method Details
#capabilities ⇒ Object
Normalized feature support used for request strategy selection.
15 |
# File 'lib/little_ghost/model.rb', line 15 def capabilities = ModelCapabilities.permissive |
#details ⇒ Object
Immutable capabilities, limits, modalities, and pricing facts.
13 14 |
# File 'lib/little_ghost/model.rb', line 13 def details = Models::Details.new(target:) # Normalized feature support used for request strategy selection. |
#model_id ⇒ Object
Provider-owned model identifier without the connection name.
9 10 |
# File 'lib/little_ghost/model.rb', line 9 def model_id = target.model_id # Logical application role that selected this model, when available. |
#role ⇒ Object
Logical application role that selected this model, when available.
11 12 |
# File 'lib/little_ghost/model.rb', line 11 def role = nil # Immutable capabilities, limits, modalities, and pricing facts. |