Class: LittleGhost::ToolExecution
- Inherits:
-
Data
- Object
- Data
- LittleGhost::ToolExecution
- Defined in:
- lib/little_ghost/tool_execution.rb,
lib/little_ghost/tool_execution.rb
Overview
Gives runtime hooks one complete view of a tool call while they prepare or observe its execution.
Instance Attribute Summary collapse
-
#context ⇒ Object
readonly
Returns the value of attribute context.
-
#events ⇒ Object
readonly
Returns the value of attribute events.
-
#operation_id ⇒ Object
readonly
Returns the value of attribute operation_id.
-
#parent_operation_id ⇒ Object
readonly
Returns the value of attribute parent_operation_id.
-
#parent_trace_context ⇒ Object
readonly
Returns the value of attribute parent_trace_context.
-
#tool ⇒ Object
readonly
Returns the value of attribute tool.
-
#tool_use ⇒ Object
readonly
Returns the value of attribute tool_use.
Instance Attribute Details
#context ⇒ Object (readonly)
Returns the value of attribute context
10 11 12 |
# File 'lib/little_ghost/tool_execution.rb', line 10 def context @context end |
#events ⇒ Object (readonly)
Returns the value of attribute events
10 11 12 |
# File 'lib/little_ghost/tool_execution.rb', line 10 def events @events end |
#operation_id ⇒ Object (readonly)
Returns the value of attribute operation_id
10 11 12 |
# File 'lib/little_ghost/tool_execution.rb', line 10 def operation_id @operation_id end |
#parent_operation_id ⇒ Object (readonly)
Returns the value of attribute parent_operation_id
10 11 12 |
# File 'lib/little_ghost/tool_execution.rb', line 10 def parent_operation_id @parent_operation_id end |
#parent_trace_context ⇒ Object (readonly)
Returns the value of attribute parent_trace_context
10 11 12 |
# File 'lib/little_ghost/tool_execution.rb', line 10 def parent_trace_context @parent_trace_context end |
#tool ⇒ Object (readonly)
Returns the value of attribute tool
10 11 12 |
# File 'lib/little_ghost/tool_execution.rb', line 10 def tool @tool end |
#tool_use ⇒ Object (readonly)
Returns the value of attribute tool_use
10 11 12 |
# File 'lib/little_ghost/tool_execution.rb', line 10 def tool_use @tool_use end |