Module: LittleGhost::Artifacts
- Defined in:
- lib/little_ghost/artifacts.rb,
lib/little_ghost/artifacts/workspace_store.rb,
lib/little_ghost/artifacts/presentation_budget.rb
Overview
Stores files from Run input and Tool results, then presents them to agents as bounded images, documents, previews, or Workspace references.
Defined Under Namespace
Classes: PresentationBudget, WorkspaceStore