Exception: LittleGhost::CleanupError

Inherits:
Error
  • Object
show all
Defined in:
lib/little_ghost/errors.rb

Overview

Raised when one or more managed resources fail to close. Treat the operation as not cleanly terminated and escalate to the application's supervisor.