Exception: LittleGhost::CleanupError
- Defined in:
- lib/little_ghost/errors.rb
Overview
Raised when one or more managed resources fail to close.
Direct Known Subclasses
Subagents::Manager::CleanupError, Support::InterruptibleStream::CleanupError
Raised when one or more managed resources fail to close.
Subagents::Manager::CleanupError, Support::InterruptibleStream::CleanupError