Module: LittleGhost::MCP
- Defined in:
- lib/little_ghost/mcp/client.rb,
lib/little_ghost/mcp/toolset.rb
Overview
Connects Agents to Tools published by Model Context Protocol servers through an application-provided official MCP Ruby client. See the MCP guide to build a client, choose a transport, manage its lifecycle, and decide which operations and application data the server may access.
Defined Under Namespace
Classes: Adapter, CatalogValidatingTransport, Session, Toolset