Module: LittleGhost::ModelInterface

Included in:
Model
Defined in:
lib/little_ghost/model.rb

Overview

Interface for executable model implementations accepted by agents.

Instance Method Summary collapse

Instance Method Details

#capabilitiesObject

Normalized feature support used for request strategy selection.



15
# File 'lib/little_ghost/model.rb', line 15

def capabilities = ModelCapabilities.permissive

#detailsObject

Immutable capabilities, limits, modalities, and pricing facts.



13
14
# File 'lib/little_ghost/model.rb', line 13

def details = Models::Details.new(target:)
# Normalized feature support used for request strategy selection.

#model_idObject

Provider-owned model identifier without the connection name.



9
10
# File 'lib/little_ghost/model.rb', line 9

def model_id = target.model_id
# Logical application role that selected this model, when available.

#roleObject

Logical application role that selected this model, when available.



11
12
# File 'lib/little_ghost/model.rb', line 11

def role = nil
# Immutable capabilities, limits, modalities, and pricing facts.

#targetObject

Canonical physical provider and model identifier.



7
8
# File 'lib/little_ghost/model.rb', line 7

def target = Models::Target.parse("custom:#{self.class.name || "anonymous"}")
# Provider-owned model identifier without the connection name.