Exception: LittleGhost::ToolError

Inherits:
Error
  • Object
show all
Defined in:
lib/little_ghost/errors.rb

Overview

Base class for expected failures while executing a Tool. Its message may be returned to the model, so it must be safe to disclose.