Class: LittleGhost::ToolExecution

Inherits:
Data
  • Object
show all
Defined in:
lib/little_ghost/tool_execution.rb,
lib/little_ghost/tool_execution.rb

Overview

Gives runtime hooks one complete view of a tool call while they prepare or observe its execution.

Instance Attribute Summary collapse

Instance Attribute Details

#contextObject (readonly)

Returns the value of attribute context

Returns:

  • (Object)

    the current value of context



10
11
12
# File 'lib/little_ghost/tool_execution.rb', line 10

def context
  @context
end

#eventsObject (readonly)

Returns the value of attribute events

Returns:

  • (Object)

    the current value of events



10
11
12
# File 'lib/little_ghost/tool_execution.rb', line 10

def events
  @events
end

#operation_idObject (readonly)

Returns the value of attribute operation_id

Returns:

  • (Object)

    the current value of operation_id



10
11
12
# File 'lib/little_ghost/tool_execution.rb', line 10

def operation_id
  @operation_id
end

#parent_operation_idObject (readonly)

Returns the value of attribute parent_operation_id

Returns:

  • (Object)

    the current value of parent_operation_id



10
11
12
# File 'lib/little_ghost/tool_execution.rb', line 10

def parent_operation_id
  @parent_operation_id
end

#parent_trace_contextObject (readonly)

Returns the value of attribute parent_trace_context

Returns:

  • (Object)

    the current value of parent_trace_context



10
11
12
# File 'lib/little_ghost/tool_execution.rb', line 10

def parent_trace_context
  @parent_trace_context
end

#toolObject (readonly)

Returns the value of attribute tool

Returns:

  • (Object)

    the current value of tool



10
11
12
# File 'lib/little_ghost/tool_execution.rb', line 10

def tool
  @tool
end

#tool_useObject (readonly)

Returns the value of attribute tool_use

Returns:

  • (Object)

    the current value of tool_use



10
11
12
# File 'lib/little_ghost/tool_execution.rb', line 10

def tool_use
  @tool_use
end