Class: LittleGhost::Tools::Filesystem::Exclusive

Inherits:
LittleGhost::Tools::Filesystem show all
Defined in:
lib/little_ghost/tools/filesystem.rb

Overview

Provides filesystem tools marked exclusive for shared workspace mutation. Read operations are also serialized so a batch cannot observe a concurrent write from another tool call in the same run.

Method Summary

Methods inherited from LittleGhost::Tools::Filesystem

tools